@@ -50,6 +50,14 @@ impl SpriteSheetAnimationState {
         *self = Self::default();
     }
 
+    /// Returns the index of the current frame
+    ///
+    /// The index is relative to the animation sequence. **not** to the sprite-sheet.
+    #[must_use]
+    pub fn current_frame_index(&self) -> usize {
+        self.current_frame
+    }
+
     /// Update the animation and the sprite (if necessary)
     ///
     /// Returns true if the animation has ended
@@ -301,7 +309,7 @@ mod tests {
             animation: SpriteSheetAnimation,
             frame_duration: Duration,
         ) {
-            assert!(!state.update(&mut sprite_at_second_frame, &animation, frame_duration))
+            assert!(!state.update(&mut sprite_at_second_frame, &animation, frame_duration));
         }
     }
 
@@ -359,7 +367,7 @@ mod tests {
                 animation: SpriteSheetAnimation,
                 frame_duration: Duration,
             ) {
-                assert!(!state.update(&mut sprite_at_second_frame, &animation, frame_duration))
+                assert!(!state.update(&mut sprite_at_second_frame, &animation, frame_duration));
             }
         }
 
@@ -406,7 +414,7 @@ mod tests {
                 animation: SpriteSheetAnimation,
                 frame_duration: Duration,
             ) {
-                assert!(!state.update(&mut sprite_at_second_frame, &animation, frame_duration))
+                assert!(!state.update(&mut sprite_at_second_frame, &animation, frame_duration));
             }
         }
     }
@@ -459,7 +467,7 @@ mod tests {
                 animation: SpriteSheetAnimation,
                 frame_duration: Duration,
             ) {
-                assert!(state.update(&mut sprite_at_second_frame, &animation, frame_duration))
+                assert!(state.update(&mut sprite_at_second_frame, &animation, frame_duration));
             }
 
             #[rstest]
